# -*- coding: utf-8 -*-
# Generated by Django 1.11 on 2017-04-15 09:41
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Attachment',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('file', models.FileField(upload_to=b'files')),
                ('name', models.CharField(blank=True, max_length=100)),
                ('position', models.PositiveSmallIntegerField()),
            ],
            options={
                'ordering': ('position',),
            },
        ),
        migrations.CreateModel(
            name='Content',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('position', models.PositiveSmallIntegerField()),
                ('content_type', models.CharField(max_length=100)),
                ('created', models.DateTimeField(auto_now_add=True, db_index=True, verbose_name=b'created')),
                ('changed', models.DateTimeField(auto_now=True, db_index=True, verbose_name=b'changed')),
            ],
            options={
                'ordering': ('position',),
            },
        ),
        migrations.CreateModel(
            name='ContentsContainer',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
            ],
        ),
        migrations.CreateModel(
            name='Number',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('number', models.IntegerField(blank=True, null=True)),
                ('suffix', models.CharField(blank=True, max_length=10, null=True)),
                ('title', models.CharField(blank=True, max_length=100)),
            ],
            options={
                'ordering': ('content', 'id'),
            },
        ),
        migrations.CreateModel(
            name='Photo',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('image', models.ImageField(upload_to=b'photos')),
                ('description', models.CharField(blank=True, max_length=255, null=True)),
                ('position', models.PositiveSmallIntegerField()),
            ],
            options={
                'ordering': ('position',),
            },
        ),
        migrations.CreateModel(
            name='Quote',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=255)),
                ('job_title', models.CharField(max_length=255)),
                ('image', models.ImageField(blank=True, null=True, upload_to=b'quotes')),
                ('title', models.CharField(blank=True, max_length=255, null=True)),
                ('quote', models.TextField()),
            ],
            options={
                'ordering': ('content', 'id'),
            },
        ),
        migrations.CreateModel(
            name='CodeInput',
            fields=[
                ('content_ptr', models.OneToOneField(auto_created=True, on_delete=django.db.models.deletion.CASCADE, parent_link=True, primary_key=True, serialize=False, to='xprez.Content')),
                ('code', models.TextField()),
            ],
            bases=('xprez.content',),
        ),
        migrations.CreateModel(
            name='CodeTemplate',
            fields=[
                ('content_ptr', models.OneToOneField(auto_created=True, on_delete=django.db.models.deletion.CASCADE, parent_link=True, primary_key=True, serialize=False, to='xprez.Content')),
                ('template_name', models.CharField(blank=True, max_length=255, null=True)),
            ],
            bases=('xprez.content',),
        ),
        migrations.CreateModel(
            name='DownloadContent',
            fields=[
                ('content_ptr', models.OneToOneField(auto_created=True, on_delete=django.db.models.deletion.CASCADE, parent_link=True, primary_key=True, serialize=False, to='xprez.Content')),
                ('title', models.CharField(blank=True, max_length=255)),
            ],
            options={
                'abstract': False,
            },
            bases=('xprez.content',),
        ),
        migrations.CreateModel(
            name='FeatureBoxes',
            fields=[
                ('content_ptr', models.OneToOneField(auto_created=True, on_delete=django.db.models.deletion.CASCADE, parent_link=True, primary_key=True, serialize=False, to='xprez.Content')),
                ('box_1', models.TextField(blank=True)),
                ('box_2', models.TextField(blank=True)),
                ('box_3', models.TextField(blank=True)),
            ],
            bases=('xprez.content',),
        ),
        migrations.CreateModel(
            name='Gallery',
            fields=[
                ('content_ptr', models.OneToOneField(auto_created=True, on_delete=django.db.models.deletion.CASCADE, parent_link=True, primary_key=True, serialize=False, to='xprez.Content')),
                ('width', models.CharField(choices=[(b'full', b'full'), (b'mid', b'mid'), (b'text', b'text')], default=b'full', max_length=50)),
                ('columns', models.PositiveSmallIntegerField(default=1)),
                ('divided', models.BooleanField(default=False)),
                ('crop', models.BooleanField(default=False)),
            ],
            options={
                'abstract': False,
            },
            bases=('xprez.content',),
        ),
        migrations.CreateModel(
            name='MediumEditor',
            fields=[
                ('content_ptr', models.OneToOneField(auto_created=True, on_delete=django.db.models.deletion.CASCADE, parent_link=True, primary_key=True, serialize=False, to='xprez.Content')),
                ('text', models.TextField()),
                ('css_class', models.CharField(blank=True, max_length=100, null=True)),
                ('box', models.BooleanField(default=False)),
                ('width', models.CharField(choices=[(b'full', b'full'), (b'mid', b'mid'), (b'text', b'text')], default=b'full', max_length=50)),
            ],
            bases=('xprez.content',),
        ),
        migrations.CreateModel(
            name='NumbersContent',
            fields=[
                ('content_ptr', models.OneToOneField(auto_created=True, on_delete=django.db.models.deletion.CASCADE, parent_link=True, primary_key=True, serialize=False, to='xprez.Content')),
            ],
            options={
                'abstract': False,
            },
            bases=('xprez.content',),
        ),
        migrations.CreateModel(
            name='QuoteContent',
            fields=[
                ('content_ptr', models.OneToOneField(auto_created=True, on_delete=django.db.models.deletion.CASCADE, parent_link=True, primary_key=True, serialize=False, to='xprez.Content')),
                ('title', models.CharField(blank=True, max_length=255, null=True)),
                ('box', models.BooleanField(default=False)),
                ('display_two', models.BooleanField(default=False)),
            ],
            options={
                'abstract': False,
            },
            bases=('xprez.content',),
        ),
        migrations.CreateModel(
            name='Video',
            fields=[
                ('content_ptr', models.OneToOneField(auto_created=True, on_delete=django.db.models.deletion.CASCADE, parent_link=True, primary_key=True, serialize=False, to='xprez.Content')),
                ('poster_image', models.ImageField(blank=True, null=True, upload_to=b'video')),
                ('url', models.URLField()),
                ('width', models.CharField(choices=[(b'full', b'full'), (b'mid', b'mid'), (b'text', b'text')], default=b'full', max_length=50)),
                ('video_type', models.CharField(choices=[(b'youtube', b'YouTube'), (b'vimeo', b'Vimeo')], max_length=50)),
                ('video_id', models.CharField(max_length=200)),
            ],
            bases=('xprez.content',),
        ),
        migrations.AddField(
            model_name='content',
            name='page',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='contents', to='xprez.ContentsContainer'),
        ),
        migrations.AddField(
            model_name='quote',
            name='content',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='quotes', to='xprez.QuoteContent'),
        ),
        migrations.AddField(
            model_name='photo',
            name='gallery',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='photos', to='xprez.Gallery'),
        ),
        migrations.AddField(
            model_name='number',
            name='content',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='numbers', to='xprez.NumbersContent'),
        ),
        migrations.AddField(
            model_name='attachment',
            name='content',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='attachments', to='xprez.DownloadContent'),
        ),
    ]



# Generated by Django 2.0.5 on 2018-05-04 13:16

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('xprez', '0003_auto_20180117_0930'),
    ]

    operations = [
        migrations.AlterField(
            model_name='video',
            name='video_type',
            field=models.CharField(choices=[('youtube', 'YouTube'), ('vimeo', 'Vimeo')], max_length=50),
        ),
    ]



from django.urls import re_path

from .views import medium_file_delete, medium_file_upload

urlpatterns = [
    re_path(r'^file-upload/(?P<directory>[/\w-]+)/$', medium_file_upload, name='medium_file_upload'),
    re_path(r'^file-delete/$', medium_file_delete, name='medium_file_delete'),
]



# Generated by Django 2.2.24 on 2022-02-08 12:51

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('xprez', '0014_remove_content_margin_top'),
    ]

    operations = [
        migrations.AddField(
            model_name='ckeditor',
            name='content_centered',
            field=models.BooleanField(default=False),
        ),
    ]



# Generated by Django 2.2.9 on 2020-02-11 16:47

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('xprez', '0008_merge_20200129_1159'),
    ]

    operations = [
        migrations.AddField(
            model_name='gridboxes',
            name='width',
            field=models.CharField(choices=[('full', 'full'), ('mid', 'mid'), ('text', 'text')], default='full', max_length=50),
        ),
    ]



from django.conf import settings as django_settings

from . import settings_default

XPREZ_DEFAULT_ALLOWED_CONTENTS = getattr(django_settings, 'XPREZ_DEFAULT_ALLOWED_CONTENTS', settings_default.DEFAULT_ALLOWED_CONTENTS)
XPREZ_DEFAULT_EXCLUDED_CONTENTS = getattr(django_settings, 'XPREZ_DEFAULT_EXCLUDED_CONTENTS', None)

XPREZ_CONTAINER_MODEL_CLASS = getattr(django_settings, 'XPREZ_CONTAINER_MODEL_CLASS', 'xprez.ContentsContainer')

XPREZ_CODE_TEMPLATES_DIR = getattr(django_settings, 'XPREZ_CODE_TEMPLATES_DIR', '')
XPREZ_CODE_TEMPLATES_PREFIX = getattr(django_settings, 'XPREZ_CODE_TEMPLATES_PREFIX', '')
XPREZ_USE_ABSOLUTE_URI = getattr(django_settings, 'XPREZ_USE_ABSOLUTE_URI', False)
XPREZ_BASE_URL = getattr(django_settings, 'XPREZ_BASE_URL', '')

XPREZ_CKEDITOR_CONFIG_SIMPLE = getattr(django_settings, 'XPREZ_CKEDITOR_CONFIG_SIMPLE', settings_default.XPREZ_CKEDITOR_CONFIG_SIMPLE)
XPREZ_CKEDITOR_CONFIG_FULL = getattr(django_settings, 'XPREZ_CKEDITOR_CONFIG_FULL', settings_default.XPREZ_CKEDITOR_CONFIG_FULL)
XPREZ_CKEDITOR_CONFIG_FULL_NO_INSERT_PLUGIN = getattr(django_settings, 'XPREZ_CKEDITOR_CONFIG_FULL_NO_INSERT_PLUGIN ', settings_default.XPREZ_CKEDITOR_CONFIG_FULL_NO_INSERT_PLUGIN)



from django import forms

from .models import CodeSnippet
from xprez.admin_forms import BaseContentForm


class CodeSnippetForm(BaseContentForm):
    class Meta:
        fields = ('position', 'title', 'lang', 'code', 'visible')
        model = CodeSnippet
        widgets = {
            'code': forms.Textarea(attrs={'class': 'js-code-snippet wide', 'cols': 100,})
        }



from copy import deepcopy

DEFAULT_ALLOWED_CONTENTS = [
    # 'mediumeditor',
    'ckeditor',
    'quotecontent',
    'gallery',
    'downloadcontent',
    'video',
    'numberscontent',
    'featureboxes',
    'codeinput',
    'codetemplate',
    'textimage',
]

XPREZ_CKEDITOR_CONFIG_SIMPLE = {
    'toolbar': ('bold', 'italic', 'link'),
    'blockToolbar': (),
}

_XPREZ_CKEDITOR_CONFIG_FULL_BASE = {
    'blockToolbar': ('heading', '|', 'blockQuote', 'bulletedList', 'numberedList',),
    'toolbar': ('bold', 'italic', 'link', '|', 'heading', '|', 'blockQuote', 'bulletedList', 'numberedList',),
    'placeholder': 'Type your text',
    'link': {
        'decorators': {
            'toggleButtonPrimary': {
                'mode': 'manual',
                'label': 'Primary button',
                'attributes': {
                    'class': 'btn btn-primary'
                }
            },
            'toggleButtonSecondary': {
                'mode': 'manual',
                'label': 'Secondary button',
                'attributes': {
                    'class': 'btn btn-secondary'
                }
            },
            'openInNewTab': {
                'mode': 'manual',
                'label': 'Open in a new tab',
                'defaultValue': False,
                'attributes': {
                    'target': '_blank',
                }
            }
        }
    },
    'heading': {
        'options': (
            {'model': 'paragraph', 'title': 'Paragraph', 'class': 'ck-heading_paragraph'},
            {'model': 'heading2', 'view': 'h2', 'title': 'Heading 2', 'class': 'ck-heading_heading2'},
            {'model': 'heading3', 'view': 'h3', 'title': 'Heading 3', 'class': 'ck-heading_heading3'},
        ),
    },
    'fontSize': {
        'options': ('tiny', 'default', 'big',)
    },

}

XPREZ_CKEDITOR_CONFIG_FULL_NO_INSERT_PLUGIN = deepcopy(_XPREZ_CKEDITOR_CONFIG_FULL_BASE)
XPREZ_CKEDITOR_CONFIG_FULL_NO_INSERT_PLUGIN['image'] = {
    'toolbar': ('|',)
}

XPREZ_CKEDITOR_CONFIG_FULL = deepcopy(_XPREZ_CKEDITOR_CONFIG_FULL_BASE)
XPREZ_CKEDITOR_CONFIG_FULL['blockToolbar'] += ('|', 'imageUpload', 'MediaEmbed',)
XPREZ_CKEDITOR_CONFIG_FULL['toolbar'] += ('|', 'imageUpload', 'MediaEmbed',)
XPREZ_CKEDITOR_CONFIG_FULL['simpleUpload'] = {'uploadUrl': None}  # filled later in CkEditor.__init__
XPREZ_CKEDITOR_CONFIG_FULL['mediaEmbed '] = {'previewsInData': True}
XPREZ_CKEDITOR_CONFIG_FULL['image'] = {
    'toolbar': ('imageTextAlternative', 'toggleImageCaption', '|', 'imageStyle:alignLeft', 'imageStyle:block', 'imageStyle:alignRight', '|', 'linkImage',),
    'styles': ('block', 'alignLeft', 'alignRight',),
}



# Generated by Django 2.0.1 on 2018-01-15 12:06

from django.db import migrations, models
import xprez.models.fields


class Migration(migrations.Migration):

    dependencies = [
        ('xprez', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='attachment',
            name='file',
            field=models.FileField(upload_to='files'),
        ),
        migrations.AlterField(
            model_name='codetemplate',
            name='template_name',
            field=xprez.models.fields.TemplatePathField(blank=True, max_length=255, null=True),
        ),
        migrations.AlterField(
            model_name='content',
            name='changed',
            field=models.DateTimeField(auto_now=True, db_index=True, verbose_name='changed'),
        ),
        migrations.AlterField(
            model_name='content',
            name='created',
            field=models.DateTimeField(auto_now_add=True, db_index=True, verbose_name='created'),
        ),
        migrations.AlterField(
            model_name='gallery',
            name='width',
            field=models.CharField(choices=[('full', 'full'), ('mid', 'mid'), ('text', 'text')], default='full', max_length=50),
        ),
        migrations.AlterField(
            model_name='mediumeditor',
            name='width',
            field=models.CharField(choices=[('full', 'full'), ('mid', 'mid'), ('text', 'text')], default='full', max_length=50),
        ),
        migrations.AlterField(
            model_name='photo',
            name='image',
            field=models.ImageField(upload_to='photos'),
        ),
        migrations.AlterField(
            model_name='quote',
            name='image',
            field=models.ImageField(blank=True, null=True, upload_to='quotes'),
        ),
        migrations.AlterField(
            model_name='video',
            name='poster_image',
            field=models.ImageField(blank=True, null=True, upload_to='video'),
        ),
        migrations.AlterField(
            model_name='video',
            name='video_type',
            field=models.CharField(choices=[('youtube', 'YouTube'), ('vimeo', 'Vimeo')], max_length=50),
        ),
        migrations.AlterField(
            model_name='video',
            name='width',
            field=models.CharField(choices=[('full', 'full'), ('mid', 'mid'), ('text', 'text')], default='full', max_length=50),
        ),
    ]



# Generated by Django 2.2.9 on 2020-01-29 10:59

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('xprez', '0007_auto_20191221_1522'),
        ('xprez', '0007_auto_20191227_2150'),
    ]

    operations = [
    ]



# Generated by Django 2.2.24 on 2022-02-08 13:01

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('xprez', '0016_auto_20220208_1355'),
    ]

    operations = [
        migrations.AlterField(
            model_name='ckeditor',
            name='width',
            field=models.CharField(choices=[('full', 'full'), ('mid', 'mid'), ('text', 'text')], default='text', max_length=50),
        ),
    ]



# Generated by Django 2.2.24 on 2021-06-29 09:12

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('xprez', '0009_gridboxes_width'),
    ]

    operations = [
        migrations.CreateModel(
            name='CkEditor',
            fields=[
                ('content_ptr', models.OneToOneField(auto_created=True, on_delete=django.db.models.deletion.CASCADE, parent_link=True, primary_key=True, serialize=False, to='xprez.Content')),
                ('text', models.TextField()),
                ('css_class', models.CharField(blank=True, max_length=100, null=True)),
                ('box', models.BooleanField(default=False)),
                ('width', models.CharField(choices=[('full', 'full'), ('mid', 'mid'), ('text', 'text')], default='full', max_length=50)),
            ],
            bases=('xprez.content',),
        ),
    ]



from django import forms
from django.urls import reverse_lazy


class MediumEditorWidget(forms.widgets.Textarea):
    FULL = 'full'
    SIMPLE = 'simple'
    FULL_NO_INSERT_PLUGIN = 'full_no_insert_plugin'
    MODE_CHOICES = [FULL, SIMPLE, FULL_NO_INSERT_PLUGIN]

    class Media:
        css = {
            'all': (
                'xprez/admin/libs/medium-editor/dist/css/medium-editor.min.css',
                'xprez/admin/libs/medium-editor/dist/css/themes/default.min.css',
                'xprez/admin/libs/medium-editor-insert-plugin/dist/css/medium-editor-insert-plugin.min.css',
                'medium_editor/css/medium_editor_widget.css',
                "//netdna.bootstrapcdn.com/font-awesome/4.1.0/css/font-awesome.css",
            )
        }
        js = (
            'xprez/admin/libs/jquery/dist/jquery.min.js',
            'xprez/admin/libs/handlebars/handlebars.min.js',
            'xprez/admin/libs/medium-editor/dist/js/medium-editor.min.js',
            'xprez/admin/libs/jquery-sortable/source/js/jquery-sortable-min.js',
            'xprez/admin/libs/blueimp-file-upload/js/vendor/jquery.ui.widget.js',
            'xprez/admin/libs/blueimp-file-upload/js/jquery.iframe-transport.js',
            'xprez/admin/libs/blueimp-file-upload/js/jquery.fileupload.js',
            'xprez/admin/libs/medium-editor-insert-plugin/dist/js/medium-editor-insert-plugin.js',
            'xprez/admin/libs/rangy/rangy-core.js',
            'xprez/admin/libs/rangy/rangy-classapplier.js',
            'medium_editor/js/medium_editor_widget.js',
        )

    def __init__(self, mode='full', file_upload_dir=None, attrs=None):
        assert mode in self.MODE_CHOICES
        if mode == self.SIMPLE:
            css_class = 'medium-editor-simple ignore-changes'
        elif mode == self.FULL:
            css_class = 'medium-editor ignore-changes'
        else:
            css_class = 'medium-editor-no-insert-plugin'
        default_attrs = {'cols': '40', 'rows': '10', 'class': css_class, }
        if attrs:
            default_attrs.update(attrs)

        if file_upload_dir:
            default_attrs['data-file-upload'] = reverse_lazy('medium_file_upload', args=[file_upload_dir])
            default_attrs['data-file-delete'] = reverse_lazy('medium_file_delete')

        super(MediumEditorWidget, self).__init__(default_attrs)



import json

from django import forms
from django.urls import reverse
from xprez import settings


class CkEditorWidget(forms.widgets.Textarea):
    template_name = 'xprez/widgets/ck_editor.html'

    class Media:
        css = {
            'all': (
                # 'ck_editor/css/ck_editor_widget.css',
            )
        }
        js = (
            'xprez/admin/libs/jquery/dist/jquery.min.js',
            'ck_editor/libs/ck_editor/ckeditor.js',
            'ck_editor/js/ck_editor_widget.js',
        )

    def __init__(self, config=None, file_upload_dir=None, attrs=None):
        if config is None:
            config = settings.XPREZ_CKEDITOR_CONFIG_FULL

        if 'simpleUpload' in config and config['simpleUpload'].get('uploadUrl') is None:
            config['simpleUpload']['uploadUrl'] = reverse('xprez:ckeditor_file_upload', args=[file_upload_dir])

        default_attrs = {
            'class': 'js-ck-editor-source',
            'data-ck-editor-config': json.dumps(config),
        }
        if attrs:
            default_attrs.update(attrs)

        super(CkEditorWidget, self).__init__(default_attrs)



# -*- coding: utf-8 -*-

from __future__ import unicode_literals

import warnings

from django import template

from .. import contents_manager
from ..settings import XPREZ_BASE_URL, XPREZ_USE_ABSOLUTE_URI
from ..utils import build_absolute_uri as build_abs_uri

register = template.Library()


@register.inclusion_tag('xprez/includes/media.html')
def xprez_front_media():
    return {
        'BASE_URL': XPREZ_BASE_URL,
        'USE_ABSOLUTE_URI': XPREZ_USE_ABSOLUTE_URI,
        'contents_media': contents_manager.front_media(),
    }


@register.simple_tag(takes_context=True)
def xprez_content_render_front(context, content):
    polymorph = content.polymorph()
    try:
        return polymorph.render_front(extra_context=context.flatten())
    except TypeError:
        warnings.warn("Deprecation warning: {} render_front() should accept context attribute.".format(type(polymorph)), DeprecationWarning)
        return polymorph.render_front()


@register.inclusion_tag('xprez/includes/medium_image.html', takes_context=True)
def medium_content_image(context, url, align, width, height, caption=None):
    return _editor_content_image(context, url, align, width, height, caption=caption)


@register.inclusion_tag('xprez/includes/ckeditor_image.html', takes_context=True)
def ckeditor_content_image(context, url, align, width, height, caption=None, alt_text=None, link_url='', link_new_window=False):
    return _editor_content_image(context, url, align, width, height, caption=caption, alt_text=alt_text, link_url=link_url, link_new_window=link_new_window)


def _editor_content_image(context, url, align, width, height, caption=None, alt_text=None, link_url='', link_new_window=False):
    MAX_SIZE = {
        'center': (1000, 1000),
        'left': (450, 450),
        'right': (450, 450),
    }

    LIGHTBOX_THRESHOLD_SIZE = {
        'center': (1200, 1200),
        'left': (550, 550),
        'right': (550, 550),
    }

    threshold_size = {'width': LIGHTBOX_THRESHOLD_SIZE[align][0], 'height': LIGHTBOX_THRESHOLD_SIZE[align][1]}
    max_size = {'width': MAX_SIZE[align][0], 'height': MAX_SIZE[align][1]}

    lightbox = threshold_size['width'] < width or threshold_size['height'] < height

    image_context = {
        'url': build_abs_uri(url),
        'align': align,
        'width': width,
        'height': height,
        'lightbox': lightbox,
        'max_size': '%sx%s' % (max_size['width'], max_size['height']),
        'link_url': link_url,
        'link_new_window': link_new_window,
        'caption': caption,
        'alt_text': alt_text,
    }

    return image_context


@register.filter()
def build_absolute_uri(url):
    return build_abs_uri(url)



# Generated by Django 2.0.1 on 2018-01-17 08:30

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('xprez', '0002_auto_20180115_1306'),
    ]

    operations = [
        migrations.CreateModel(
            name='TextImage',
            fields=[
                ('content_ptr', models.OneToOneField(auto_created=True, on_delete=django.db.models.deletion.CASCADE, parent_link=True, primary_key=True, serialize=False, to='xprez.Content')),
                ('image', models.ImageField(upload_to='text_image_images')),
                ('text', models.TextField()),
                ('image_alignment', models.CharField(choices=[('left', 'Left'), ('right', 'Right')], default='left', max_length=15)),
            ],
            options={
                'abstract': False,
            },
            bases=('xprez.content',),
        ),
        migrations.AlterField(
            model_name='video',
            name='video_type',
            field=models.CharField(choices=[('vimeo', 'Vimeo'), ('youtube', 'YouTube')], max_length=50),
        ),
    ]



# -*- coding: utf-8 -*-
from os import makedirs, path

from django.conf import settings as django_settings
from django.contrib.admin.views.decorators import staff_member_required
from django.db import models
from django.http import JsonResponse
from django.template import TemplateDoesNotExist
from django.template.defaultfilters import striptags
from django.template.loader import get_template
from django.urls import re_path
from django.utils.decorators import method_decorator
from django.views.decorators.csrf import csrf_exempt
from xprez.utils import random_string

from .. import contents_manager, settings
from ..ck_editor import parse_text as ckeditor_parse_text
from ..ck_editor.widgets import CkEditorWidget
from ..medium_editor.utils import parse_text as medium_editor_parse_text
from ..medium_editor.utils import \
    render_text_parsed as medium_editor_render_text_parsed
from ..medium_editor.widgets import MediumEditorWidget
from .base import (AjaxUploadFormsetContent, Content, ContentItem,
                   FormsetContent)
from .fields import TemplatePathField

try:
    from django.db.models import JSONField
except ImportError:
    from django.contrib.postgres.fields import JSONField


PHOTOSWIPE_JS = ('xprez/libs/photoswipe/dist/photoswipe.min.js', 'xprez/libs/photoswipe/dist/photoswipe-ui-default.min.js', 'xprez/js/photoswipe.js')
PHOTOSWIPE_CSS = ('xprez/libs/photoswipe/dist/photoswipe.css', 'xprez/libs/photoswipe/dist/default-skin/default-skin.css')


class MediumEditor(Content):
    form_class = 'xprez.admin_forms.MediumEditorForm'
    admin_template_name = 'xprez/admin/contents/medium_editor.html'
    front_template_name = 'xprez/contents/medium_editor.html'
    icon_name = 'text_content'
    verbose_name = 'Text Content'

    text = models.TextField()
    # css_class = models.CharField(max_length=100, null=True, blank=True)
    box = models.BooleanField(default=False)
    width = models.CharField(max_length=50, choices=Content.SIZE_CHOICES, default=Content.SIZE_FULL)

    class AdminMedia:
        js = MediumEditorWidget.Media.js
        css = MediumEditorWidget.Media.css['all']

    def show_front(self):
        return striptags(self.text) != ''

    def get_parsed_text(self):
        return medium_editor_parse_text(self.text)

    def render_text(self):
        return medium_editor_render_text_parsed(self.get_parsed_text())


class CkEditorFileUploadMixin:
    @classmethod
    @method_decorator(staff_member_required)
    @method_decorator(csrf_exempt)
    def file_upload_view(cls, request, directory):
        if request.method == 'POST':
            file_data = request.FILES['upload']
            name = file_data.name
            random_dir_name = random_string(16)
            full_directory = path.join(django_settings.MEDIA_ROOT, directory, random_dir_name)
            if not path.isdir(full_directory):
                makedirs(full_directory)

            with open(path.join(full_directory, name), 'wb+') as destination:
                for chunk in file_data.chunks():
                    destination.write(chunk)

            filename = path.join(directory, random_dir_name, name)

            return JsonResponse({
                'url': django_settings.MEDIA_URL + filename
            })

    @classmethod
    def get_urls(cls):
        cls_name = cls.__name__.lower()
        return [
            re_path(r'^{}/file-upload/(?P<directory>[/\w-]+)/$'.format(cls_name), cls.file_upload_view, name='{}_file_upload'.format(cls_name)),
        ]


class CkEditor(CkEditorFileUploadMixin, Content):
    form_class = 'xprez.admin_forms.CkEditorForm'
    admin_template_name = 'xprez/admin/contents/ck_editor.html'
    front_template_name = 'xprez/contents/ck_editor.html'
    icon_name = 'text_content'
    verbose_name = 'Text Content'

    text = models.TextField()
    # css_class = models.CharField(max_length=100, null=True, blank=True)
    box = models.BooleanField(default=False)
    width = models.CharField(max_length=50, choices=Content.SIZE_CHOICES, default=Content.SIZE_TEXT)
    content_centered = models.BooleanField(default=False)

    class AdminMedia:
        js = CkEditorWidget.Media.js + PHOTOSWIPE_JS
        css = CkEditorWidget.Media.css['all'] + PHOTOSWIPE_CSS

    def show_front(self):
        # TODO: not working for single image inserted in editor
        return striptags(self.text) != ''

    def render_front(self, extra_context={}):
        extra_context['parsed_text'] = ckeditor_parse_text.render_text_parsed(
            ckeditor_parse_text.parse_text(self.text, extra_context['request'])
        )
        return super().render_front(extra_context=extra_context)


class QuoteContent(FormsetContent):
    form_class = 'xprez.admin_forms.QuoteContentForm'
    formset_factory = 'xprez.admin_forms.QuoteFormSet'
    admin_template_name = 'xprez/admin/contents/quote.html'
    front_template_name = 'xprez/contents/quote.html'
    icon_name = 'quote'
    verbose_name = 'Quote'

    title = models.CharField(max_length=255, null=True, blank=True)
    box = models.BooleanField(default=False)

    display_two = models.BooleanField(default=False)

    def get_formset_queryset(self):
        return self.quotes.all()

    def show_front(self):
        quotes = self.quotes.all()
        if len(quotes) == 0:
            return False
        quote = quotes.first()
        if not quote.name or not quote.quote:
            return False
        return True


class Quote(ContentItem):
    content_foreign_key = 'content'
    content = models.ForeignKey(QuoteContent, related_name='quotes', on_delete=models.CASCADE)
    name = models.CharField(max_length=255)
    job_title = models.CharField(max_length=255)
    image = models.ImageField(upload_to='quotes', null=True, blank=True)
    title = models.CharField(max_length=255, null=True, blank=True)
    quote = models.TextField()
    # position = models.PositiveSmallIntegerField()

    class Meta:
        ordering = ('content', 'id')


class Gallery(AjaxUploadFormsetContent):

    COLUMNS_CHOICES = (
        (1, '1'),
        (2, '2'),
        (3, '3'),
        (4, '4'),
        (6, '6'),
        (8, '8'),
    )

    form_class = 'xprez.admin_forms.GalleryForm'
    admin_template_name = 'xprez/admin/contents/gallery/gallery.html'
    admin_formset_item_template_name = 'xprez/admin/contents/gallery/photo.html'
    front_template_name = 'xprez/contents/gallery.html'
    icon_name = 'gallery'
    verbose_name = 'Gallery / Image'
    formset_factory = 'xprez.admin_forms.PhotoFormSet'

    width = models.CharField(max_length=50, choices=Content.SIZE_CHOICES, default=Content.SIZE_FULL)
    columns = models.PositiveSmallIntegerField(default=1)
    divided = models.BooleanField(default=False)
    crop = models.BooleanField(default=False)

    def get_formset_queryset(self):
        return self.photos.all()

    def save_admin_form(self, request):
        super(Gallery, self).save_admin_form(request)
        for index, photo in enumerate(self.photos.all()):
            photo.position = index
            photo.save()

    class FrontMedia:
        js = PHOTOSWIPE_JS
        css = PHOTOSWIPE_CSS

    def show_front(self):
        return self.photos.all().count()


class Photo(ContentItem):
    content_foreign_key = 'gallery'
    gallery = models.ForeignKey(Gallery, related_name='photos', on_delete=models.CASCADE)
    image = models.ImageField(upload_to='photos')
    description = models.CharField(max_length=255, blank=True, null=True)
    alt_text = models.CharField(max_length=255, blank=True)
    position = models.PositiveSmallIntegerField()

    @classmethod
    def create_from_file(cls, django_file, gallery):
        photo = cls(gallery=gallery)
        photo.position = gallery.photos.all().count()
        photo.image.save(django_file.name.split("/")[-1], django_file)
        photo.save()
        return photo

    class Meta:
        ordering = ('position', )
        # unique_together = (
        #     ('gallery', 'position', )
        # )


class Video(Content):
    TYPE_CHOICES = (
        ('youtube', 'YouTube'),
        ('vimeo', 'Vimeo'),
    )
    admin_template_name = 'xprez/admin/contents/video.html'
    front_template_name = 'xprez/contents/video.html'
    verbose_name = 'Video'
    icon_name = 'video'
    form_class = 'xprez.admin_forms.VideoForm'

    poster_image = models.ImageField(upload_to='video', null=True, blank=True)
    url = models.URLField()
    width = models.CharField(max_length=50, choices=Content.SIZE_CHOICES, default=Content.SIZE_FULL)
    video_type = models.CharField(choices=TYPE_CHOICES, max_length=50)
    video_id = models.CharField(max_length=200)

    def save_admin_form(self, request):
        inst = self.admin_form.save(commit=False)
        inst.video_type = self.admin_form.video_type
        inst.video_id = self.admin_form.video_id
        inst.save()

    def show_front(self):
        return self.url

    class FrontMedia:
        js = ('xprez/js/video.js', '//www.youtube.com/iframe_api', 'xprez/libs/froogaloop/froogaloop.min.js',)


class CodeInput(Content):
    admin_template_name = 'xprez/admin/contents/code_input.html'
    front_template_name = 'xprez/contents/code_input.html'
    verbose_name = 'Code Input'
    icon_name = 'code'
    form_class = 'xprez.admin_forms.CodeInputForm'

    code = models.TextField()

    def show_front(self):
        return self.code


class NumbersContent(FormsetContent):
    admin_template_name = 'xprez/admin/contents/numbers.html'
    front_template_name = 'xprez/contents/numbers.html'
    verbose_name = 'Numbers'
    icon_name = 'numbers'
    form_class = 'xprez.admin_forms.NumbersContentForm'
    formset_factory = 'xprez.admin_forms.NumberFormSet'

    def get_formset_queryset(self):
        return self.numbers.all()

    def show_front(self):
        return self.numbers.all().count()

    class FrontMedia:
        js = ('xprez/libs/jquery.waypoints.min.js', 'xprez/libs/counter.up/jquery.counterup.js', 'xprez/js/numbers.js')


class Number(ContentItem):
    content_foreign_key = 'content'
    content = models.ForeignKey(NumbersContent, related_name='numbers', on_delete=models.CASCADE)
    number = models.IntegerField(null=True, blank=True)
    suffix = models.CharField(max_length=10, null=True, blank=True)
    title = models.CharField(max_length=100, blank=True)

    class Meta:
        ordering = ('content', 'id')


class FeatureBoxes(Content):
    admin_template_name = 'xprez/admin/contents/feature_boxes.html'
    front_template_name = 'xprez/contents/feature_boxes.html'
    verbose_name = 'Feature Boxes'
    icon_name = 'feature_boxes'
    form_class = 'xprez.admin_forms.FeatureBoxesForm'

    box_1 = models.TextField(blank=True)
    box_2 = models.TextField(blank=True)
    box_3 = models.TextField(blank=True)

    def show_front(self):
        return bool(self.box_1)


class CodeTemplate(Content):
    admin_template_name = 'xprez/admin/contents/code_template.html'
    verbose_name = 'Code Template'
    icon_name = 'code_template'
    form_class = 'xprez.admin_forms.CodeTemplateForm'

    template_name = TemplatePathField(template_dir=settings.XPREZ_CODE_TEMPLATES_DIR, prefix=settings.XPREZ_CODE_TEMPLATES_PREFIX, max_length=255, null=True, blank=True)

    def show_front(self):
        return self.template_name

    def render_front(self, extra_context=None):
        if self.show_front():
            context = extra_context or {}
            context['content'] = self
            try:
                return get_template(self.template_name).render(context=context)
            except TemplateDoesNotExist:
                return 'Invalid Template'
        else:
            return ''


class DownloadContent(AjaxUploadFormsetContent):
    admin_template_name = 'xprez/admin/contents/download/download.html'
    front_template_name = 'xprez/contents/download.html'
    admin_formset_item_template_name = 'xprez/admin/contents/download/attachment.html'

    verbose_name = 'Files'
    icon_name = 'files'
    form_class = 'xprez.admin_forms.DownloadContentForm'
    formset_factory = 'xprez.admin_forms.AttachmentFormSet'

    title = models.CharField(max_length=255, blank=True)

    def get_formset_queryset(self):
        return self.attachments.all()

    def show_front(self):
        return self.attachments.all().count()


class Attachment(ContentItem):
    content_foreign_key = 'content'
    content = models.ForeignKey(DownloadContent, related_name='attachments', on_delete=models.CASCADE)
    file = models.FileField(upload_to='files', max_length=300)
    name = models.CharField(max_length=100, blank=True)
    position = models.PositiveSmallIntegerField()

    def get_name(self):
        return self.name or self.get_default_file_name()

    def get_extension(self):
        try:
            return self.file.name.split('/')[-1].split('.')[-1].lower()
        except (KeyError, IndexError):
            return ''

    def get_default_file_name(self):
        try:
            return self.file.name.split('/')[-1].split('.')[0]
        except (KeyError, IndexError):
            return 'unnamed'

    @classmethod
    def create_from_file(cls, django_file, content):
        att = cls(content=content)
        att.position = content.attachments.all().count()
        att.file.save(django_file.name.split("/")[-1], django_file)
        att.save()
        return att

    class Meta:
        ordering = ('position', )


class TextImageBase(Content):
    form_class = 'xprez.admin_forms.TextImageForm'
    admin_template_name = 'xprez/admin/contents/text_image.html'
    front_template_name = 'xprez/contents/text_image.html'
    verbose_name = 'Image + Text'
    icon_name = 'text_image'

    ALIGNMENT_LEFT = 'left'
    ALIGNMENT_RIGHT = 'right'
    IMAGE_ALIGNMENT_CHOICES = (
        (ALIGNMENT_LEFT, 'Left'),
        (ALIGNMENT_RIGHT, 'Right'),
    )

    image = models.ImageField(upload_to='text_image_images')
    text = models.TextField()
    image_alignment = models.CharField(choices=IMAGE_ALIGNMENT_CHOICES, default=ALIGNMENT_LEFT, max_length=15)
    # css_class = models.CharField(max_length=100, null=True, blank=True)

    class AdminMedia:
        js = CkEditorWidget.Media.js
        css = CkEditorWidget.Media.css['all']

    class Meta:
        abstract = True

    def show_front(self):
        return True

    def render_front(self, extra_context={}):
        extra_context['parsed_text'] = ckeditor_parse_text.render_text_parsed(
            ckeditor_parse_text.parse_text(self.text, extra_context['request'])
        )
        return super().render_front(extra_context=extra_context)

    # def show_front(self):
    #     return striptags(self.text) != ''

    # def get_parsed_text(self):
    #     return medium_editor_parse_text(self.text)

    # def render_text(self):
    #     return medium_editor_render_text_parsed(self.get_parsed_text())


class TextImage(TextImageBase):

    class Meta:
        abstract = False


class GridBoxes(CkEditorFileUploadMixin, Content):
    form_class = 'xprez.admin_forms.GridBoxesForm'
    admin_template_name = 'xprez/admin/contents/grid_boxes/grid_boxes.html'
    front_template_name = 'xprez/contents/grid_boxes.html'
    verbose_name = 'Grid Boxes'
    icon_name = 'grid_boxes'

    MARGIN_CHOICES = (
        ('none', 'none'),
        ('m', 'm'),
        ('l', 'l'),
    )

    TEXT_SIZE_CHOICES = (
        ('xs', 'xs'),
        ('s', 's'),
        ('m', 'm'),
    )

    class AdminMedia:
        js = CkEditorWidget.Media.js + ('xprez/admin/js/grid_boxes.js',)
        css = CkEditorWidget.Media.css['all']

    columns = models.PositiveSmallIntegerField(default=2)
    margin = models.CharField(max_length=4, choices=MARGIN_CHOICES, default='m')
    width = models.CharField(max_length=50, choices=Content.SIZE_CHOICES, default=Content.SIZE_FULL)
    text_size = models.CharField(max_length=2, choices=TEXT_SIZE_CHOICES, default='m')

    padded = models.BooleanField(default=True)
    content_centered = models.BooleanField(default=False)
    edge_images = models.BooleanField(default=False)
    boxes_filled = models.BooleanField(default=True)
    border = models.BooleanField(default=True)
    boxes = JSONField(null=True)

    def render_front(self, extra_context={}):
        boxes = []
        for box_content in (self.boxes or []):
            if striptags(box_content != ''):
                # boxes.append(medium_editor_render_text_parsed(medium_editor_parse_text(box_content)))
                boxes.append(ckeditor_parse_text.render_text_parsed(
                    ckeditor_parse_text.parse_text(box_content, extra_context['request'])
                ))

        extra_context['rendered_boxes'] = boxes
        return super().render_front(extra_context=extra_context)

    def show_front(self):
        for box_content in (self.boxes or []):
            if striptags(box_content != ''):
                return True
        return False


contents_manager.register(MediumEditor)
contents_manager.register(CkEditor)
contents_manager.register(QuoteContent)
contents_manager.register(Gallery)
contents_manager.register(DownloadContent)
contents_manager.register(Video)
contents_manager.register(NumbersContent)
contents_manager.register(FeatureBoxes)
contents_manager.register(CodeInput)
contents_manager.register(CodeTemplate)
contents_manager.register(TextImage)
contents_manager.register(GridBoxes)



# Generated by Django 2.2.24 on 2022-03-12 17:45

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('xprez', '0017_auto_20220208_1401'),
    ]

    operations = [
        migrations.AlterField(
            model_name='attachment',
            name='file',
            field=models.FileField(max_length=300, upload_to='files'),
        ),
    ]



from pathlib import Path

from django.utils.text import slugify
from sorl.thumbnail.base import EXTENSIONS, ThumbnailBackend
from sorl.thumbnail.conf import settings
from sorl.thumbnail.helpers import serialize, tokey


class NamingThumbnailBackendMixin(object):
    def _get_thumbnail_filename(self, source, geometry_string, options):
        """
        Computes the destination filename.
        """
        key = tokey(source.key, geometry_string, serialize(options))
        # make some subdirs
        path = '%s/%s/%s' % (key[:2], key[2:4], key)
        # get filename_stem from options or use source name
        filename_stem = slugify(options.get('filename_stem') or Path(source.name).stem)
        # print('stem', filename_stem, Path(source.name).stem)
        return '%s%s/%s.%s' % (settings.THUMBNAIL_PREFIX, path, filename_stem, EXTENSIONS[options['format']])


class NamingThumbnailBackend(NamingThumbnailBackendMixin, ThumbnailBackend):
    pass



# Generated by Django 2.2.25 on 2022-02-04 14:43

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('xprez', '0010_ckeditor'),
    ]

    operations = [
        migrations.RenameField(
            model_name='mediumeditor',
            old_name='css_class',
            new_name='css_class_old',
        ),
        migrations.RenameField(
            model_name='ckeditor',
            old_name='css_class',
            new_name='css_class_old',
        ),
        migrations.RenameField(
            model_name='textimage',
            old_name='css_class',
            new_name='css_class_old',
        ),
        migrations.AddField(
            model_name='content',
            name='css_class',
            field=models.CharField(blank=True, max_length=100, null=True),
        ),
        migrations.AddField(
            model_name='content',
            name='margin_bottom',
            field=models.PositiveSmallIntegerField(choices=[(0, 'None'), (1, 'S'), (2, 'M'), (3, 'L'), (4, 'XL')], default=2),
        ),
        migrations.AddField(
            model_name='content',
            name='margin_top',
            field=models.PositiveSmallIntegerField(choices=[(0, 'None'), (1, 'S'), (2, 'M'), (3, 'L'), (4, 'XL')], default=2),
        ),
    ]



# Generated by Django 2.2.25 on 2022-02-04 15:00

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('xprez', '0011_auto_20220204_1559'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='mediumeditor',
            name='css_class_old',
        ),
        migrations.RemoveField(
            model_name='ckeditor',
            name='css_class_old',
        ),
        migrations.RemoveField(
            model_name='textimage',
            name='css_class_old',
        ),
    ]



from collections import OrderedDict

from django.utils.module_loading import autodiscover_modules


class ContentTypeManager:

    def get(self, content_type):
        return self._registry[content_type]

    def all_as_list(self):
        return [content_type for key, content_type in self._registry.items()]

    def get_urls(self):
        urls = []
        for key, content in self._registry.items():
            urls += content.get_urls()
        return urls

    def _collect_media(self, media_class_name):
        from .utils import remove_duplicates

        js = []
        css = []
        for key, content in self._registry.items():
            media_class = getattr(content, media_class_name)
            js += list(getattr(media_class, 'js', []))
            css += list(getattr(media_class, 'css', []))
        return {
            'js': remove_duplicates(js),
            'css': remove_duplicates(css),
        }

    def admin_media(self):
        return self._collect_media('AdminMedia')

    def front_media(self):
        return self._collect_media('FrontMedia')

    def __init__(self):
        self._registry = OrderedDict()

    def register(self, content_class):
        self._registry[content_class.identifier()] = content_class

    def unregister(self, content_class):
        del self._registry[content_class.identifier()]


contents_manager = ContentTypeManager()


def autodiscover():
    autodiscover_modules('models', register_to=contents_manager)



try:
    import urlparse
except ImportError:
    import urllib.parse as urlparse
import json

from django import forms
from django.forms import inlineformset_factory
from django.utils.translation import gettext_lazy as _

from . import settings
from .ck_editor.widgets import CkEditorWidget
from .medium_editor.widgets import MediumEditorWidget
from .models import (Attachment, CkEditor, CodeInput, CodeTemplate,
                     DownloadContent, FeatureBoxes, Gallery, GridBoxes,
                     MediumEditor, Number, NumbersContent, Photo, Quote,
                     QuoteContent, TextImage, Video)


class BaseContentForm(forms.ModelForm):
    class Meta:
        fields = ('position', 'visible', 'css_class', 'margin_bottom')


class GalleryForm(BaseContentForm):
    class Meta:
        model = Gallery
        fields = ('width', 'columns', 'divided', 'crop',) + BaseContentForm.Meta.fields


class MediumEditorForm(BaseContentForm):
    class Meta:
        model = MediumEditor
        fields = ('text', 'box', 'width',) + BaseContentForm.Meta.fields
        widgets = {
            'text': MediumEditorWidget(file_upload_dir='medium_editor_uploads')
        }


class CkEditorForm(BaseContentForm):
    class Meta:
        model = CkEditor
        fields = ('text', 'content_centered', 'box', 'width',) + BaseContentForm.Meta.fields
        widgets = {
            'text': CkEditorWidget(file_upload_dir='ck_editor_uploads')
        }


class QuoteForm(forms.ModelForm):
    class Meta:
        model = Quote
        fields = ('id', 'name', 'job_title', 'title', 'quote', 'image')
        widgets = {
            'title': forms.TextInput(attrs={'class': 'long'}),
            'quote': forms.Textarea(attrs={'class': 'long'}),
        }


class QuoteContentForm(BaseContentForm):
    class Meta:
        model = QuoteContent
        fields = ('display_two', 'title', 'box',) + BaseContentForm.Meta.fields


class VideoForm(BaseContentForm):

    def clean_url(self):
        url = self.cleaned_data['url']
        parsed_url = urlparse.urlparse(url)
        url_query = urlparse.parse_qs(parsed_url.query)

        if 'youtube' in url:
            try:
                self.video_id = url_query.get('v')[0]
            except (KeyError, TypeError):
                raise forms.ValidationError(_('Error in parsing video ID from youtube'))
            self.video_type = 'youtube'
        elif 'vimeo' in url:
            self.video_id = url.split('/')[-1]
            self.video_type = 'vimeo'
        else:
            raise forms.ValidationError(_('Unsupported Video URL, it should be in format: "https://www.youtube.com/watch?v=nNGBxXN7QC0" or "https://vimeo.com/210073083" '))
        return url

    class Meta:
        model = Video
        fields = ('poster_image', 'url', 'width',) + BaseContentForm.Meta.fields
        widgets = {
            'url': forms.URLInput(attrs={'class': 'long'}),
        }


class CodeInputForm(BaseContentForm):
    class Meta:
        model = CodeInput
        fields = ('code',) + BaseContentForm.Meta.fields


class NumbersContentForm(BaseContentForm):
    class Meta:
        model = NumbersContent
        fields = BaseContentForm.Meta.fields


class NumberForm(forms.ModelForm):
    class Meta:
        model = Number
        widgets = {
            'number': forms.NumberInput(attrs={'class': 'short'}),
            'suffix': forms.TextInput(attrs={'class': 'short'}),
        }
        fields = ('id', 'number', 'suffix', 'title', )


class FeatureBoxesForm(BaseContentForm):
    class Meta:
        model = FeatureBoxes
        fields = ('box_1', 'box_2', 'box_3',) + BaseContentForm.Meta.fields
        widgets = {
            'box_1': MediumEditorWidget(mode=MediumEditorWidget.FULL_NO_INSERT_PLUGIN),
            'box_2': MediumEditorWidget(mode=MediumEditorWidget.FULL_NO_INSERT_PLUGIN),
            'box_3': MediumEditorWidget(mode=MediumEditorWidget.FULL_NO_INSERT_PLUGIN),
        }


class CodeTemplateForm(BaseContentForm):

    class Meta:
        model = CodeTemplate
        fields = ('template_name',) + BaseContentForm.Meta.fields


class DownloadContentForm(BaseContentForm):
    class Meta:
        model = DownloadContent
        fields = ('title',) + BaseContentForm.Meta.fields
        widgets = {
            'title': forms.TextInput(attrs={'placeholder': 'Files'})
        }


class TextImageForm(BaseContentForm):
    class Meta:
        model = TextImage
        fields = ('image', 'text', 'image_alignment',) + BaseContentForm.Meta.fields
        widgets = {
            'text': CkEditorWidget(config=settings.XPREZ_CKEDITOR_CONFIG_FULL_NO_INSERT_PLUGIN),
        }


class GridBoxesForm(BaseContentForm):
    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)
        self.ckeditor_widget_tpl = CkEditorWidget(config=settings.XPREZ_CKEDITOR_CONFIG_FULL)  # TODO: cleanup

    class Meta:
        model = GridBoxes
        fields = ('columns', 'margin', 'width', 'text_size', 'padded', 'content_centered', 'edge_images', 'boxes_filled', 'border', 'boxes') + BaseContentForm.Meta.fields


AttachmentFormSet = inlineformset_factory(DownloadContent, Attachment, fields=('id', 'name', 'position'), extra=0, can_delete=True)
PhotoFormSet = inlineformset_factory(Gallery, Photo, fields=('id', 'description', 'alt_text', 'position'), extra=0, can_delete=True)
QuoteFormSet = inlineformset_factory(QuoteContent, Quote, form=QuoteForm, fields=('id', 'name', 'job_title', 'title', 'quote', 'image'), max_num=2, can_delete=True)
NumberFormSet = inlineformset_factory(NumbersContent, Number, form=NumberForm, fields=('id', 'number', 'suffix', 'title'), max_num=4, extra=4, can_delete=True)



import os
from django.db import models
from ..form_fields import RelativeFilePathFieldForm


class TemplatePathField(models.FilePathField):

    def __init__(self, template_dir='', prefix='', **kwargs):
        self.template_dir = template_dir
        self.prefix = prefix
        super(TemplatePathField, self).__init__(**kwargs)

    def formfield(self, **kwargs):
        absolute_path = os.path.join(self.template_dir, self.prefix)
        defaults = {
            'path': absolute_path,
            'rel_path': self.prefix,
            'form_class': RelativeFilePathFieldForm
        }
        defaults.update(kwargs)
        return super(TemplatePathField, self).formfield(**defaults)


# Generated by Django 2.1 on 2019-12-15 15:22

import django.contrib.postgres.fields
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('xprez', '0005_auto_20191025_1352'),
    ]

    operations = [
        migrations.CreateModel(
            name='GridBoxes',
            fields=[
                ('content_ptr', models.OneToOneField(auto_created=True, on_delete=django.db.models.deletion.CASCADE, parent_link=True, primary_key=True, serialize=False, to='xprez.Content')),
                ('columns', models.PositiveSmallIntegerField(default=2)),
                ('margin', models.CharField(choices=[('none', 'none'), ('m', 'm'), ('l', 'l')], default='m', max_length=4)),
                ('text_size', models.CharField(choices=[('xs', 'xs'), ('s', 's'), ('m', 'm')], default='m', max_length=2)),
                ('padded', models.BooleanField(default=True)),
                ('content_centered', models.BooleanField(default=False)),
                ('edge_images', models.BooleanField(default=False)),
                ('boxes_filled', models.BooleanField(default=True)),
                ('border', models.BooleanField(default=True)),
                ('boxes', django.contrib.postgres.fields.ArrayField(base_field=models.TextField(), null=True, size=None)),
            ],
            bases=('xprez.content',),
        ),
    ]



from bs4 import BeautifulSoup
import urllib
import sys

try:
    import cStringIO
except ImportError:
    import io

from PIL import Image

from django.template import Template, Context
from django.utils.safestring import mark_safe


def parse_text(text_source):
    if not text_source:
        return ''
    soup = BeautifulSoup(text_source, 'html5lib')

    # extract empty p elements from end of text
    for last_p in reversed(soup.find_all('p')):
        if last_p.text:
            break
        else:
            last_p.extract()

    for tag in soup.find_all('div', attrs={'class': 'medium-insert-images'}):
        tag_img = tag.find('img')
        if tag_img:
            url = tag_img.get('src')
            if sys.version_info >= (3, 0):
                file = io.BytesIO(urllib.request.urlopen(url).read())
            else:
                file = cStringIO.StringIO(urllib.urlopen(url).read())
            im = Image.open(file)
            width, height = im.size
            if 'medium-insert-images-right' in tag['class']:
                align = 'right'
            elif 'medium-insert-images-left' in tag['class']:
                align = 'left'
            else:
                align = 'center'

            caption_tag = tag.find('figcaption')
            if caption_tag:
                caption = caption_tag.text
            else:
                caption = ''

            tag.replaceWith('{%% medium_content_image "%s" "%s" %s %s "%s" %%}' % (url, align, width, height, caption))

    for tag in soup.find_all(attrs={'contenteditable': True}):
        del tag['contenteditable']

    if sys.version_info >= (3, 0):
        text_parsed = str(soup)
    else:
        text_parsed = unicode(soup)
    return text_parsed


def render_text_parsed(text_parsed, extra_context={}):
    t = Template('{% load xprez %}' + text_parsed)
    c = Context({})
    c.update(extra_context)
    return mark_safe(t.render(c))



# -*- coding: utf-8 -*-
# Generated by Django 1.11 on 2017-04-15 13:36
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('xprez', '0001_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='CodeSnippet',
            fields=[
                ('content_ptr', models.OneToOneField(auto_created=True, on_delete=django.db.models.deletion.CASCADE, parent_link=True, primary_key=True, serialize=False, to='xprez.Content')),
                ('title', models.CharField(blank=True, max_length=150, null=True)),
                ('code', models.TextField()),
                ('lang', models.CharField(choices=[(b'python', b'Python'), (b'js', b'JavaScript'), (b'django_template', b'Django Template'), (b'php', b'PHP'), (b'xml', b'XML')], default=b'python', max_length=20, verbose_name=b'Jazyk')),
            ],
            bases=('xprez.content',),
        ),
    ]



# Generated by Django 2.2.24 on 2022-02-08 12:55

from django.db import migrations


def migrate_ckeditor_width(apps, schema_editor):
    """
    When not boxed, force width to "Text width"
    """

    CkEditor = apps.get_model('xprez.CkEditor')
    CkEditor.objects.filter(box=False).update(width='text')


def noop(*args, **kwargs):
    pass


class Migration(migrations.Migration):

    dependencies = [
        ('xprez', '0015_ckeditor_content_centered'),
    ]

    operations = [
        migrations.RunPython(migrate_ckeditor_width, noop)
    ]
